@@ -3,6 +3,7 @@
 
 /*
  * Copyright (C) 2001 Havoc Pennington
+ * Copyright (C) 2006-2007 Vincent Untz
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -60,9 +61,6 @@ char*       _wnck_window_get_name_for_display (WnckWindow *window,
                                                gboolean    use_state_decorations);
 const char* _wnck_window_get_startup_id (WnckWindow *window);
 
-const char* _wnck_window_get_resource_class (WnckWindow *window);
-const char* _wnck_window_get_resource_name  (WnckWindow *window);
-
 time_t      _wnck_window_get_needs_attention_time (WnckWindow *window);
 time_t      _wnck_window_or_transient_get_needs_attention_time (WnckWindow *window);
 
@@ -109,6 +107,7 @@ gboolean _wnck_workspace_set_geometry (WnckWorkspace *space, int w, int h);
 gboolean _wnck_workspace_set_viewport (WnckWorkspace *space, int x, int y);
 
 void _wnck_init (void);
+Display *_wnck_get_default_display (void);
 
 #define DEFAULT_ICON_WIDTH 32
 #define DEFAULT_ICON_HEIGHT 32
